@@ -88,6 +88,20 @@ pub static ATOMS: &'static [&'static str] = &[
     "http://www.w3.org/2000/svg",
     "http://www.w3.org/1998/Math/MathML",
 
+    "#text",
+    "#comment",
+    "#document",
+    "#document-fragment",
+
+    // User agent strings
+    "4.0",
+    "Gecko",
+    "Linux",
+    "Mac",
+    "Mozilla",
+    "Netscape",
+    "Win32",
+
     "abbr",
     "abort",
     "abs",
@@ -219,10 +233,12 @@ pub static ATOMS: &'static [&'static str] = &[
     "beforescriptexecute",
     "beforeunload",
     "begin",
+    "bevel",
     "bevelled",
     "bgcolor",
     "bias",
     "blink",
+    "blob",
     "border",
     "border-bottom",
     "border-bottom-color",
@@ -249,6 +265,7 @@ pub static ATOMS: &'static [&'static str] = &[
     "border-top-width",
     "border-width",
     "bottom",
+    "butt",
     "bvar",
     "by",
     "calcmode",
@@ -327,6 +344,7 @@ pub static ATOMS: &'static [&'static str] = &[
     "csymbol",
     "curl",
     "cursor",
+    "customevent",
     "cx",
     "cy",
     "d",
@@ -396,6 +414,7 @@ pub static ATOMS: &'static [&'static str] = &[
     "error",
     "eulergamma",
     "event",
+    "events",
     "exists",
     "exp",
     "exponent",
@@ -469,6 +488,8 @@ pub static ATOMS: &'static [&'static str] = &[
     "filterRes",
     "filterunits",
     "filterUnits",
+    "float",
+    "flood",
     "flood-color",
     "flood-opacity",
     "floor",
@@ -541,6 +562,7 @@ pub static ATOMS: &'static [&'static str] = &[
     "href",
     "hreflang",
     "hspace",
+    "htmlevents",
     "http-equiv",
     "i",
     "icon",
@@ -554,6 +576,7 @@ pub static ATOMS: &'static [&'static str] = &[
     "imaginaryi",
     "img",
     "implies",
+    "important",
     "in",
     "in2",
     "index",
@@ -581,14 +604,18 @@ pub static ATOMS: &'static [&'static str] = &[
     "kernelunitlength",
     "kernelUnitLength",
     "kerning",
+    "keyboardevent",
     "keydown",
+    "keyevents",
     "keygen",
     "keypoints",
     "keyPoints",
+    "keypress",
     "keysplines",
     "keySplines",
     "keytimes",
     "keyTimes",
+    "keyup",
     "label",
     "lambda",
     "lang",
@@ -686,6 +713,7 @@ pub static ATOMS: &'static [&'static str] = &[
     "menuitem",
     "merror",
     "message",
+    "messageevent",
     "metadata",
     "meter",
     "method",
@@ -699,16 +727,21 @@ pub static ATOMS: &'static [&'static str] = &[
     "minus",
     "min-width",
     "missing-glyph",
+    "miter",
     "mlabeledtr",
     "mmultiscripts",
     "mn",
     "mo",
     "mode",
-    "month",
     "moment",
     "momentabout",
-    "movablelimits",
+    "month",
+    "mousedown",
+    "mouseevent",
+    "mouseevents",
     "mouseover",
+    "mouseup",
+    "movablelimits",
     "mover",
     "mozbrowser",
     "mpadded",
@@ -729,6 +762,7 @@ pub static ATOMS: &'static [&'static str] = &[
     "mtext",
     "mtr",
     "multicol",
+    "multipart/form-data",
     "multiple",
     "munder",
     "munderover",
@@ -739,6 +773,7 @@ pub static ATOMS: &'static [&'static str] = &[
     "neq",
     "nest",
     "nextid",
+    "no message",
     "nobr",
     "noembed",
     "nohref",
@@ -757,8 +792,10 @@ pub static ATOMS: &'static [&'static str] = &[
     "numoctaves",
     "numOctaves",
     "occurrence",
+    "off",
     "offset",
     "ol",
+    "on",
     "onabort",
     "onactivate",
     "onafterprint",
@@ -910,6 +947,7 @@ pub static ATOMS: &'static [&'static str] = &[
     "polygon",
     "polyline",
     "position",
+    "post",
     "poster",
     "power",
     "prefetch",
@@ -933,6 +971,7 @@ pub static ATOMS: &'static [&'static str] = &[
     "radio",
     "radiogroup",
     "radius",
+    "range",
     "rationals",
     "rb",
     "readonly",
@@ -964,6 +1003,7 @@ pub static ATOMS: &'static [&'static str] = &[
     "requiredfeatures",
     "requiredFeatures",
     "reset",
+    "resize",
     "restart",
     "result",
     "rev",
@@ -971,6 +1011,7 @@ pub static ATOMS: &'static [&'static str] = &[
     "role",
     "root",
     "rotate",
+    "round",
     "rowalign",
     "rowlines",
     "rows",
@@ -1036,6 +1077,7 @@ pub static ATOMS: &'static [&'static str] = &[
     "speed",
     "spreadmethod",
     "spreadMethod",
+    "square",
     "src",
     "srcdoc",
     "standby",
@@ -1097,6 +1139,7 @@ pub static ATOMS: &'static [&'static str] = &[
     "tel",
     "tendsto",
     "text",
+    "text/plain",
     "text-align",
     "text-anchor",
     "text-decoration",
@@ -1112,6 +1155,7 @@ pub static ATOMS: &'static [&'static str] = &[
     "times",
     "to",
     "top",
+    "touchevent",
     "transform",
     "transition-delay",
     "transition-duration",
@@ -1127,6 +1171,8 @@ pub static ATOMS: &'static [&'static str] = &[
     "u",
     "u1",
     "u2",
+    "uievent",
+    "uievents",
     "ul",
     "underline-position",
     "underline-thickness",
@@ -1140,6 +1186,7 @@ pub static ATOMS: &'static [&'static str] = &[
     "url",
     "use",
     "usemap",
+    "UTF-8",
     "valign",
     "v-alphabetic",
     "value",
